>From 8338d0ff8d0db2e1757d757e3b4987117ae86a50 Mon Sep 17 00:00:00 2001
From: Joseph Tulou <brezhoneg1@yahoo.fr>
Date: Wed, 28 Jan 2009 12:02:23 +0100
Subject: [PATCH] scaling toggle updated
   - takes vout-filter design into account
   - implementation at the vout plugin level
---
 modules/video_filter/filter_common.h |    2 ++
 modules/video_output/x11/xcommon.c   |   10 ++++++++++
 src/video_output/vout_intf.c         |    3 +--
 3 files changed, 13 insertions(+), 2 deletions(-)

diff --git a/modules/video_filter/filter_common.h b/modules/video_filter/filter_common.h
index 2efc052..14ebdc5 100644
--- a/modules/video_filter/filter_common.h
+++ b/modules/video_filter/filter_common.h
@@ -90,11 +90,13 @@ static int SetParentVal( vlc_object_t *p_this, char const *psz_var,
 
 #define ADD_PARENT_CALLBACKS( handler ) \
     var_AddCallback( p_vout, "fullscreen", handler, NULL );                   \
+    var_AddCallback( p_vout, "scaling", handler, NULL );                      \
     var_AddCallback( p_vout, "aspect-ratio", handler, NULL );                 \
     var_AddCallback( p_vout, "crop", handler, NULL );
 
 #define DEL_PARENT_CALLBACKS( handler ) \
     var_DelCallback( p_vout, "fullscreen", handler, NULL );                   \
+    var_DelCallback( p_vout, "scaling", handler, NULL );                      \
     var_DelCallback( p_vout, "aspect-ratio", handler, NULL );                 \
     var_DelCallback( p_vout, "crop", handler, NULL );
 
diff --git a/modules/video_output/x11/xcommon.c b/modules/video_output/x11/xcommon.c
index 5ba486d..0de99fa 100644
--- a/modules/video_output/x11/xcommon.c
+++ b/modules/video_output/x11/xcommon.c
@@ -1478,6 +1478,16 @@ static int ManageVideo( vout_thread_t *p_vout )
         p_vout->i_changes &= ~VOUT_FULLSCREEN_CHANGE;
     }
 
+    /* scaling/no-scaling toggle */
+    if( p_vout->i_changes & VOUT_SCALE_CHANGE )
+    {
+        p_vout->i_changes &= ~VOUT_SCALE_CHANGE;
+
+        p_vout->b_scale = var_GetBool( p_vout, "scaling" );
+
+        p_vout->i_changes |= VOUT_SIZE_CHANGE;
+    }
+
     if( p_vout->i_changes & VOUT_CROP_CHANGE ||
         p_vout->i_changes & VOUT_ASPECT_CHANGE )
     {
diff --git a/src/video_output/vout_intf.c b/src/video_output/vout_intf.c
index 89cc527..781f890 100644
--- a/src/video_output/vout_intf.c
+++ b/src/video_output/vout_intf.c
@@ -1217,8 +1217,7 @@ static int ScalingCallback( vlc_object_t *p_this, char const *psz_cmd,
 
     vlc_mutex_lock( &p_vout->change_lock );
 
-    p_vout->b_scale = newval.b_bool;
-    p_vout->i_changes |= VOUT_SIZE_CHANGE;
+    p_vout->i_changes |= VOUT_SCALE_CHANGE;
 
     vlc_mutex_unlock( &p_vout->change_lock );
 
-- 
1.5.2.5

